button {
    color: #000000;
}

#big_timer_label {
    font: 24px "Courier Pitch";
    color: #000000;
}

#small_timer_label {
    font: 18px "Courier Pitch";
    color: #000000;
}

#label_title {
    font: 24px "DejaVu Sans";
    color: #000000;
}

#label_info {
    font: 15px "DejaVu Sans";
    color: #000000;
}

#playlist_color_indicator:selected {
    color: #0505b8;
}

/*
 * Uncomment this if you prefer a monospace playlist font
 */
/*
#play_list {
    font: 15px "Monospace";
}
*/
